summaryrefslogtreecommitdiff
path: root/src/include/taler_testing_lib.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-01-17 22:06:44 +0100
committerChristian Grothoff <christian@grothoff.org>2020-01-17 22:06:44 +0100
commite57dcc4b528338d80e8b50948e0c16fbf170237e (patch)
treeb38f9bd7b5e3d94c074f4ab3171d658d9297d694 /src/include/taler_testing_lib.h
parent005272da432f0bf47d584ed750acdd0eca65d11d (diff)
downloadexchange-e57dcc4b528338d80e8b50948e0c16fbf170237e.tar.gz
exchange-e57dcc4b528338d80e8b50948e0c16fbf170237e.tar.bz2
exchange-e57dcc4b528338d80e8b50948e0c16fbf170237e.zip
doxy fix
Diffstat (limited to 'src/include/taler_testing_lib.h')
-rw-r--r--src/include/taler_testing_lib.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/taler_testing_lib.h b/src/include/taler_testing_lib.h
index f884cd991..04fbde6ee 100644
--- a/src/include/taler_testing_lib.h
+++ b/src/include/taler_testing_lib.h
@@ -867,7 +867,7 @@ TALER_TESTING_cmd_bank_debits (const char *label,
*
* @param label command label.
* @param amount amount to transfer.
* @param account_base_url base URL of the account that implements this
* wire transer (which account gives money).
* @param auth authentication data to use
* @param payto_credit_account which account receives money.
@@ -878,7 +878,7 @@ TALER_TESTING_cmd_bank_debits (const char *label,
struct TALER_TESTING_Command
TALER_TESTING_cmd_transfer (const char *label,
const char *amount,
- const char *account_base_url,
+ const char *bank_base_url,
const struct TALER_BANK_AuthenticationData *auth,
const char *payto_debit_account,
const char *payto_credit_account,
@@ -867,7 +867,7 @@ TALER_TESTING_cmd_bank_debits (const char *label,
* @param label command label.
* @param amount amount to transfer.
- * @param account_base_url base URL of the account that implements this
+ * @param bank_base_url base URL of the account that implements this
* wire transer (which account gives money).
* @param auth authentication data to use